#!perl
#
#
package  Docs::US_DOD::CDRL;

use strict;
use warnings;
use warnings::register;

use vars qw($VERSION $DATE);
$VERSION = '1.07';
$DATE = '2003/07/05';

use vars qw($IDENTIFICATION_NUMBER $TITLE $REVISION $REVISION_DATE);
$IDENTIFICATION_NUMBER  = '';
$TITLE = 'Contract Data Requirements List (CDRL)';
$REVISION = '';
$REVISION_DATE = '';

1

__END__

=head1 DATA ITEM DESCRIPTION

The following establishes the data general and content
requirements for the identified data item. 

=head1 1. TITLE

Contract Data Requirements List (CDRL) 

=head1 4. NOTES

This is a stub document provided to resolve POD links.
Because of time contraints and priorities do not
expect it any actual content in the near or far future.


## end of file ##
